[AWARE] Update match filter validation for solicited/active

For solicited/active filters the match filter of the publisher
is private and is not transmitted to the subscriber. Therefore,
the service discovery callback only provides the subscriber's
own match filter. Test script updated to reflect behavior.

Bug: 36371061
Test: pass previous fail point, separate bug for continued failure
Change-Id: Ie7db82bf3f17757f91aa1ccbe4887b418376a646
diff --git a/acts/tests/google/wifi/aware/functional/DiscoveryTest.py b/acts/tests/google/wifi/aware/functional/DiscoveryTest.py
index 200a0a4..eae4670 100644
--- a/acts/tests/google/wifi/aware/functional/DiscoveryTest.py
+++ b/acts/tests/google/wifi/aware/functional/DiscoveryTest.py
@@ -177,8 +177,9 @@
         s_dut, aconsts.SESSION_CB_ON_SERVICE_DISCOVERED)
     peer_id_on_sub = discovery_event["data"][aconsts.SESSION_CB_KEY_PEER_ID]
 
     # Subscriber: validate contents of discovery (specifically that getting the
     # Publisher's SSI and MatchFilter!)
     autils.assert_equal_strings(
         bytes(discovery_event["data"][
             aconsts.SESSION_CB_KEY_SERVICE_SPECIFIC_INFO]).decode("utf-8"),
@@ -187,7 +188,9 @@
     asserts.assert_equal(
         autils.decode_list(
             discovery_event["data"][aconsts.SESSION_CB_KEY_MATCH_FILTER_LIST]),
-        autils.decode_list(p_config[aconsts.DISCOVERY_KEY_MATCH_FILTER_LIST]),
+        autils.decode_list(p_config[aconsts.DISCOVERY_KEY_MATCH_FILTER_LIST]
+                           if ptype == aconsts.PUBLISH_TYPE_UNSOLICITED else
+                           s_config[aconsts.DISCOVERY_KEY_MATCH_FILTER_LIST]),
         "Discovery mismatch: match filter")
 
     # Subscriber: send message to peer (Publisher)
@@ -246,7 +249,9 @@
     asserts.assert_equal(
         autils.decode_list(
             discovery_event["data"][aconsts.SESSION_CB_KEY_MATCH_FILTER_LIST]),
-        autils.decode_list(p_config[aconsts.DISCOVERY_KEY_MATCH_FILTER_LIST]),
+        autils.decode_list(p_config[aconsts.DISCOVERY_KEY_MATCH_FILTER_LIST]
+                           if ptype == aconsts.PUBLISH_TYPE_UNSOLICITED else
+                           s_config[aconsts.DISCOVERY_KEY_MATCH_FILTER_LIST]),
         "Discovery mismatch: match filter")
 
     # Subscribe: update subscribe and wait for confirmation
@@ -177,8 +177,9 @@
     peer_id_on_sub = discovery_event["data"][aconsts.SESSION_CB_KEY_PEER_ID]
 
-    # Subscriber: validate contents of discovery (specifically that getting the
-    # Publisher's SSI and MatchFilter!)
+    # Subscriber: validate contents of discovery:
+    # - SSI: publisher's
+    # - Match filter: UNSOLICITED - publisher, SOLICITED - subscriber
     autils.assert_equal_strings(
         bytes(discovery_event["data"][